Inherited methods
Method new()
constructor
Usage
RAVEAbstarctElectrode$new(subject, number, quiet = FALSE)
Arguments
subject
character or RAVESubject instance
number
current electrode number or reference ID
quiet
reserved, whether to suppress warning messages
Method set_reference()
set reference for instance
Usage
RAVEAbstarctElectrode$set_reference(reference)
Arguments
reference
NULL or RAVEAbstarctElectrode instance
Method set_epoch()
set epoch instance for the electrode
Usage
RAVEAbstarctElectrode$set_epoch(epoch, stitch_events = NULL)
Arguments
epoch
characters or RAVEEpoch instance. For
characters, make sure "epoch_<name>.csv" is in meta folder.
stitch_events
events to stitch, default is NULL, meaning
when loading data, the time is relative to the trial onset (column
"Time" in the epoch file); set to a character of length 2,
representing the events if time is not relative to trial onset. Please
remove the prefix. For example, for a column named "Event_name",
the event name is "name".
Method clear_cache()
method to clear cache on hard drive
Usage
RAVEAbstarctElectrode$clear_cache(...)
Arguments
...
implemented by child instances
Method clear_memory()
method to clear memory
Usage
RAVEAbstarctElectrode$clear_memory(...)
Arguments
...
implemented by child instances
Method load_data_with_epochs()
method to load electrode data
Usage
RAVEAbstarctElectrode$load_data_with_epochs(type)
Arguments
type
data type such as "power", "phase",
"voltage", "wavelet-coefficient", or others
depending on child class implementations
Method load_data()
alias of load_data_with_epochs for legacy code
Usage
RAVEAbstarctElectrode$load_data(type)
Arguments
type
see load_data_with_epochs
Method load_dimnames_with_epochs()
get expected dimension names
Usage
RAVEAbstarctElectrode$load_dimnames_with_epochs(type)
Arguments
type
see load_data_with_epochs
Method load_data_with_blocks()
load electrode block-wise data (with reference),
useful when epoch is absent
Usage
RAVEAbstarctElectrode$load_data_with_blocks(blocks, type, simplify = TRUE)
Arguments
blocks
session blocks
type
data type such as "power", "phase",
"voltage", "wavelet-coefficient".
simplify
whether to simplify the result
Method load_blocks()
alias of load_data_with_blocks for legacy code
Usage
RAVEAbstarctElectrode$load_blocks(blocks, type, simplify = TRUE)
Arguments
blocks, type, simplify
see load_data_with_blocks
Method load_dim_with_blocks()
get expected dimension information for block-based loader
Usage
RAVEAbstarctElectrode$load_dim_with_blocks(blocks, type)
Arguments
blocks, type
see load_data_with_blocks
Method clone()
The objects of this class are cloneable with this method.
Usage
RAVEAbstarctElectrode$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.