powered by
Convert electrode table
convert_electrode_table_to_bids( subject, space = c("ScanRAS", "MNI305", "fsnative") )
A list of table in data frame and a list of meta information
'RAVE' subject
suggested coordinate space, notice this argument might not be supported when 'FreeSurfer' reconstruction is missing.
'FreeSurfer'
# Run `install_subject("DemoSubject")` first! if( has_rave_subject("demo/DemoSubject") ) { convert_electrode_table_to_bids( "demo/DemoSubject", space = "ScanRAS" ) }
Run the code above in your browser using DataLab